#!/usr/bin/env python
# coding=utf-8
import sys

import click

from . import __version__
from .utils import expand, stdout_write
from .wattic import run

CONTEXT_SETTINGS = {
    'help_option_names': ['-h', '--help'],
}


@click.command(context_settings=CONTEXT_SETTINGS)
@click.option(
    'config_file', '-c', '--config',
    metavar='<yaml-config-file>',
    help='Config file, or WATTIC_CONFIG from env, defaults to ~/.wattic.yml',
    default=expand('~/.wattic.yml'), envvar='WATTIC_CONFIG',
    type=click.Path(exists=True)
)
@click.option('verbose', '-v', '--verbose', count=True, default=0,
              help='Increase verbosity')
@click.option('just_listem', '-l', '--list', count=True, default=0,
              help='List the repos and ids')
@click.option('--stats', '-s', is_flag=True, default=False,
              help='Show stats')
@click.option('--only-create', is_flag=True, default=False,
              help='Run only create command and skip prune command')
@click.option('--only-prune', is_flag=True, default=False,
              help='Skip creating new archive and run only prune command')
@click.option('--dry-run', is_flag=True, default=False,
              help='Dry-run, don\'t run the commands')
@click.option('show_version', '-V', '--version', is_flag=True, default=False,
              help='Show version and exit'
              )
@click.argument('args', nargs=-1)
def main(*args, **kwargs):
    show_version = kwargs.pop('show_version', None)
    if show_version:
        return stdout_write('python {python}, wattic {wattic}\n'.format(
            python=sys.version.split(None, 1)[0],
            wattic=__version__,
        ))
    return run(*args, **kwargs)


if __name__ == '__main__':
    main()
