import hashlib
import os
import sys

import six
import yaml


def parse_config(filepath):
    config = {}
    if os.path.exists(filepath):
        with open(filepath) as fpoint:
            config = yaml.load(fpoint) or {}
    return [
        config.get('repositories', {}),
        config.get('prune-rules', {}),
    ]


def expand(paths):
    if isinstance(paths, six.string_types):
        res = os.path.expanduser(paths)
        res = os.path.expandvars(res)
        return os.path.normpath(res)
    elif isinstance(paths, list):
        return [expand(path) for path in paths]
    return paths


def iter_repositories(repositories):
    if not repositories:
        return

    index = 0
    for repository, conf in sorted(repositories.items()):
        for prefix, setup in sorted(conf.items()):
            yield index, repository, prefix, setup
            index += 1


def stdout_write(line):
    sys.stdout.write(line)
    sys.stdout.flush()


def sha12(item1, items2):
    text = '{0}:{1}'.format(item1, items2)
    if not isinstance(text, six.binary_type):
        text = text.encode('utf-8')
    return hashlib.sha1(text).hexdigest()[:12]


def get_repo_archive_name(repository, archive):
    return '{0}::{1}'.format(repository, archive)
